@@ -17,8 +17,8 @@ from transformers import pipeline
 from sentence_transformers import SentenceTransformer, util
 from sklearn.metrics.pairwise import cosine_similarity
 similarity_model = SentenceTransformer('distilbert-base-nli-stsb-mean-tokens')
-path = os.getcwd()
-os.chdir(path)
+
+os.path.join(setup.py, 'data/embeddings.csv')
 
 #%% 
 #Classification Model
@@ -29,7 +29,7 @@ classifier = pipeline('text-classification', model=model, tokenizer=tokenizer) #
 #%%
 
 def load_embeddings(path):
-    return pd.read_csv(path + '/data/embeddings.csv')
+    return pd.read_csv('data/embeddings.csv')
 
 def predict(text_input):
     #running the classification model to predict the classes
